function phi = orthpoly_evaluate_all(T, x)
%%  Evaluate 0th through nth orthogonal polynomial at x
%   Parameters
%     T: Tridiagonal matrix encoding the three term recurrence
%        size is (n+1)x(n+1)
%     x: evaluation points
%
%  Returns
%    phi: Polynomials 0 through n at x
%         Method:  Spectrally solve (T-XI)u = constant * (last column of I)
%         WARNING: potential for dividing by 0
%         1st row of phi is 1 -- for w not a probability measure
%                divide by 1/sqrt(c), where c is the total weight
%                of the real line
n=size(T,1);
[H, Lambda] = eig(T);Lambda = diag(Lambda); Hn = H(end, :)';
for m = 1:length(x),
    xi = x(m);
    % generate the u vector as in (2.5)
    u = H * (Hn./(Lambda - xi));
    phi(:,m) = u/u(1);
end


